## ############################################################################
##
## The 2022 Europe Report of the Lancet Countdown on Health and Climate Change:
##                 towards a climate resilient future
##
## Indicator 1.2.2: Drought Indicator
##
## ############################################################################
##
## Authors: 
## - Balakrishnan Solaraju Murali, ORCID: 0000-0003-0013-3295
## - Nube González Reviriego, ORCID: 0000-0002-5919-6701
##
## Contributor:
## - Prof. Rachel Lowe, ORCID: 0000-0003-3939-7343
##
## Contact information: balakrishnan.solaraju@bsc.es
## 
## ############################################################################

# Wrapper functions to handle climate data to estimate SPEI

spX_crossvalid <- function(acc_data, ref.start, ref.end, na.rm=TRUE, method = 'parametric', distribution='log-Logistic', fit='ub-pwm'){
  
  if (!(method %in% c('parametric', 'non-parametric'))) {
    stop('pcX script error: SPEI can be only computed using the following approach: parametric or non-parametric')
  }
  
  ftime= as.numeric(dim(acc_data)['time'])
  n_sdates= as.numeric(dim(acc_data)['sdate'])
  
  spei_mod <- array(data= NA, dim=c(ftime,n_sdates))
  
  for(f in 1:ftime){
   
    #Accum_D_temp <- array(data=NA, dim=c(n_sdates))

    Accum_D_temp <- acc_data[f,]
    
    if(method=='parametric'){
      x_spei_mod <- speiX_crossvalid(Accum_D_temp, na.rm=TRUE, method = 'parametric', distribution=distribution, fit = "ub-pwm", ref.start=NULL, ref.end=NULL, x=FALSE)
      spei_mod_temp <- x_spei_mod$fitted
    }else{
      x_spei_mod <- speiX_crossvalid(Accum_D_temp, na.rm=TRUE, method = 'non-parametric', distribution=distribution)
      spei_mod_temp <- x_spei_mod
    }
    
    spei_mod[f,] <- spei_mod_temp
  }
  return(spei_mod)
}
